@@ -1,7 +1,7 @@
 package Yukki;
-$Yukki::VERSION = '0.990_002'; # TRIAL
+$Yukki::VERSION = '0.991_001'; # TRIAL
 
-$Yukki::VERSION = '0.990002';use v5.24;
+$Yukki::VERSION = '0.991001';use v5.24;
 use utf8;
 use Moo;
 
@@ -13,7 +13,7 @@ use Yukki::Types qw( AccessLevel YukkiSettings );
 use Yukki::Error qw( http_throw );
 
 use Crypt::SaltedHash;
-use List::MoreUtils qw( any );
+use List::Util qw( any );
 use Type::Params qw( validate );
 use Type::Utils;
 use Types::Standard qw( Dict HashRef Str Undef slurpy );
@@ -185,7 +185,7 @@ Yukki - Yet Uh-nother wiki
 
 =head1 VERSION
 
-version 0.990_002
+version 0.991_001
 
 =head1 DESCRIPTION
 
