@@ -1,7 +1,7 @@
 package Yukki::Types;
-$Yukki::Types::VERSION = '0.990_002'; # TRIAL
+$Yukki::Types::VERSION = '0.991_001'; # TRIAL
 
-$Yukki::Types::VERSION = '0.990002';use v5.24;
+$Yukki::Types::VERSION = '0.991001';use v5.24;
 use utf8;
 
 use Type::Library -base, -declare => qw(
@@ -18,8 +18,7 @@ use Types::Standard qw( Str Int ArrayRef Maybe HashRef Dict );
 use Types::URI qw( Uri );
 
 use Email::Address;
-use List::Util qw( first );
-use List::MoreUtils qw( all );
+use List::Util qw( first all );
 
 use namespace::clean;
 
@@ -139,7 +138,7 @@ Yukki::Types - standard types for use in Yukki
 
 =head1 VERSION
 
-version 0.990_002
+version 0.991_001
 
 =head1 SYNOPSIS
 
