@@ -1,7 +1,7 @@
 package Yukki::Web::Router;
-$Yukki::Web::Router::VERSION = '0.990_002'; # TRIAL
+$Yukki::Web::Router::VERSION = '0.991_001'; # TRIAL
 
-$Yukki::Web::Router::VERSION = '0.990002';use v5.24;
+$Yukki::Web::Router::VERSION = '0.991001';use v5.24;
 use utf8;
 use Moo;
 
@@ -11,7 +11,7 @@ use Yukki::Web::Router::Route;
 
 use Types::Standard qw( ArrayRef Str );
 use Type::Utils qw( class_type declare as where );
-use List::MoreUtils qw( all );
+use List::Util qw( all );
 
 use namespace::clean;
 
@@ -136,7 +136,7 @@ Yukki::Web::Router - send requests to the correct controllers, yo
 
 =head1 VERSION
 
-version 0.990_002
+version 0.991_001
 
 =head1 DESCRIPTION
 
