@@ -1,7 +1,7 @@
 package Yukki::Web::Router::Route;
-$Yukki::Web::Router::Route::VERSION = '0.990_002'; # TRIAL
+$Yukki::Web::Router::Route::VERSION = '0.991_001'; # TRIAL
 
-$Yukki::Web::Router::Route::VERSION = '0.990002';use v5.24;
+$Yukki::Web::Router::Route::VERSION = '0.991001';use v5.24;
 use utf8;
 use Moo;
 
@@ -11,7 +11,7 @@ use Yukki::Types qw( AccessLevel );
 use Yukki::Web::Router::Route::Match;
 
 use Types::Standard qw( ArrayRef HashRef Tuple );
-use List::MoreUtils qw( any );
+use List::Util qw( any );
 
 use namespace::clean;
 
@@ -135,7 +135,7 @@ Yukki::Web::Router::Route - Adds ACLs to routes
 
 =head1 VERSION
 
-version 0.990_002
+version 0.991_001
 
 =head1 DESCRIPTION
 
