@@ -1,11 +1,10 @@
 package Yukki::Web::View;
-$Yukki::Web::View::VERSION = '0.990_002'; # TRIAL
+$Yukki::Web::View::VERSION = '0.991_001'; # TRIAL
 
-$Yukki::Web::View::VERSION = '0.990002';use v5.24;
+$Yukki::Web::View::VERSION = '0.991001';use v5.24;
 use utf8;
 use Moo;
 
-use File::Slurp qw( read_file );
 use Type::Params qw( validate );
 use Scalar::Util qw( blessed reftype );
 use Spreadsheet::Engine;
@@ -170,9 +169,8 @@ sub prepare_template {
             ]);
     my ($template, $directives) = @{$opt}{qw( template directives )};
 
-    my $template_content = read_file(
-        $self->app->locate_dir('template_path', $template)
-    );
+    my $template_content =
+        $self->app->locate_dir('template_path', $template)->slurp;
 
     return Template::Pure->new(
         template   => $template_content,
@@ -343,7 +341,7 @@ Yukki::Web::View - base class for Yukki::Web views
 
 =head1 VERSION
 
-version 0.990_002
+version 0.991_001
 
 =head1 DESCRIPTION
 
